const ID_NO_PERSON = null;

export default {
    created() {
        this.ID_NO_PERSON = ID_NO_PERSON;
    },
    methods: {
        removePersonalNote(item) {
            console.log("removing personal note", item);
        },
        editPersonalNote(personID) {
            console.log("editing personal note of person", personID);
            this.editedPersonID = personID;
            this.updatePersonalNote();
            this.dialog = true;
        },
        updatePersonalNote() {
            let personalNote = this.personalNoteByStudentID(this.editedPersonID);
            this.editedTardiness = personalNote.tardiness || 0;
            this.editedAbsent = personalNote.absent || false;
            this.editedExcused = personalNote.excused || false;
            this.editedExcuseType = personalNote.excuse_type || null;
            this.editedExtraMarks = personalNote.extra_marks || [];
        },
        personalNoteByStudentID(studentID) {
            if (this.editedPersonID === ID_NO_PERSON) {
                return {};
            }
            return this.personalNotes.filter(item => item.student.id === studentID)[0] || {};
        }
    },
    props: ["personalNotes", "groups", "excuseTypes", "extraMarks"],
    name: "personal-notes",
    data: () => {
        return {
            dialog: false,
            // Absent versp. exc. type hw note
            editPersonalNoteId: null,
            editedPersonID: ID_NO_PERSON,
            editedTardiness: 0,
            editedAbsent: false,
            editedExcused: false,
            editedExcuseType: null,
            editedExtraMarks: [],
        }
    },
    computed: {
        persons() {
            // go through each group and get the students
            // use the group names as headers for the v-select

            return this.groups.map(
                group => {
                    return [
                        {header: group.name, id: group.short_name},
                        group.members
                    ]
                }
            ).flat(2);
        }
    },
    template: `
    <v-dialog
      v-model="dialog"
      max-width="600px"
    >
      <template v-slot:activator="{ on, attrs }">
        <div>
          <v-chip class="ma-1" v-for="personal_note in personalNotes" close
          @click="editPersonalNote(personal_note.student.id)" @click:close="removePersonalNote(personal_note)">
            {{personal_note.student.full_name}}: {{personal_note.tardiness}}
          </v-chip>
        </div>
        <v-btn
          class="ma-1"
          color="primary"
          icon
          outlined
          v-bind="attrs"
          v-on="on"
        >
          <v-icon>
            mdi-plus
          </v-icon>
        </v-btn>
      </template>
      <v-card>
        <v-card-title>
          <span class="text-h5">Personal Note</span>
        </v-card-title>
        <v-card-text>
          <v-container>
<!--            FIXME: Sync values with data-->
            <v-select item-text="full_name" item-value="id" :items="persons"
            v-model="editedPersonID" @input="updatePersonalNote"></v-select>
            <v-text-field label="Tardiness" suffix="min" type="number" min="0" v-model="editedTardiness"></v-text-field>
            <v-checkbox label="Absent" v-model="personalNoteByStudentID(editedPersonID).absent"></v-checkbox>
            <v-checkbox label="Excused" v-model="editedExcused"></v-checkbox>
          </v-container>
<!--          <small>*indicates required field</small>-->
        </v-card-text>
        <v-card-actions>
          <v-spacer></v-spacer>
          <v-btn
            color="blue darken-1"
            text
            @click="dialog = false"
          >
            Close
          </v-btn>
          <v-btn
            color="blue darken-1"
            text
            @click="dialog = false"
          >
            Save
          </v-btn>
        </v-card-actions>
      </v-card>
    </v-dialog>
    `
}